#!/usr/bin/env python

from scapy.all import *
import sys, signal, threading, string, time

if len(sys.argv) != 4:
	print "Usage: %s <destination> <port> <iface>"
	sys.exit(1)

destination = sys.argv[1]
port = sys.argv[2]
iface = sys.argv[3]

C2S = []
S2C = []

C2S_last = None
S2C_last = None

def dump( data, filename, header ):

	print "[+] Writing inter arrival times to \"%s\"." % filename
	fd = open(filename, "w")
	fd.write(header + "\n" + data + "\n")
	fd.close()

def process( pkt ):

	global S2C_last
	global C2S_last

	if not Raw in pkt:
		return

	length = len(pkt["Raw"])
	# Ignore packets without payload (e.g. TCP ACKs).
	if length == 0:
		return

	now = time.time()
	if pkt["IP"].dst == destination:
		if C2S_last == None:
			C2S_last = now
			return
		last_pkt = C2S_last
		C2S.append(now - last_pkt)
		print "C -> S: %f" % (now - last_pkt)
		C2S_last = now
	else:
		if S2C_last == None:
			S2C_last = now
			return
		last_pkt = S2C_last
		S2C.append(now - last_pkt)
		print "C <- S: %f" % (now - last_pkt)
		S2C_last = now


if __name__ == '__main__':

	try:
		sniff(iface=iface, filter="host %s and port %s" % (destination, port), \
			prn=lambda pkt: process(pkt))
	except KeyboardInterrupt:
		print "\n[+] Stopping sniffing."

	dump(string.join([str(x) for x in C2S], "\n"), \
		"C2S.txt", "C2S")
	dump(string.join([str(x) for x in S2C], "\n"), \
		"S2C.txt", "S2C")
